Index: orxonox/trunk/src/subprojects/collision_detection/Makefile.am
===================================================================
--- orxonox/trunk/src/subprojects/collision_detection/Makefile.am	(revision 4678)
+++ orxonox/trunk/src/subprojects/collision_detection/Makefile.am	(revision 4679)
@@ -35,4 +35,54 @@
                    $(MAINSRCDIR)/lib/gui/gui_gtk.cc \
                    $(MAINSRCDIR)/world_entities/test_entity.cc \
+                   $(MAINSRCDIR)/world_entities/environment.cc \
+                   $(MAINSRCDIR)/util/animation/animation.cc \
+                   $(MAINSRCDIR)/util/animation/animation_player.cc \
+                   $(MAINSRCDIR)/util/animation/animation3d.cc \
                    $(MAINSRCDIR)/world_entities/world_entity.cc
-		   
+
+
+
+
+#                   $(MAINSRCDIR)/util/loading/game_loader.cc \
+#                   $(MAINSRCDIR)/util/track/track_manager.cc \
+#                   $(MAINSRCDIR)/util/track/track_node.cc \
+#                   $(MAINSRCDIR)/util/track/pilot_node.cc \
+#                   $(MAINSRCDIR)/util/animation/animation.cc \
+#                   $(MAINSRCDIR)/util/animation/animation3d.cc \
+#                   $(MAINSRCDIR)/util/animation/animation_player.cc \
+#                   $(MAINSRCDIR)/util/object_manager.cc \
+#                   $(MAINSRCDIR)/util/garbage_collector.cc \
+#                   $(MAINSRCDIR)/util/resource_manager.cc \
+#                   $(MAINSRCDIR)/util/loading/factory.cc \
+#                   $(MAINSRCDIR)/util/loading/load_param.cc \
+#                   $(MAINSRCDIR)/util/state.cc \
+#                   $(MAINSRCDIR)/world_entities/world_entity.cc \
+#                   $(MAINSRCDIR)/world_entities/camera.cc \
+#                   $(MAINSRCDIR)/world_entities/player.cc \
+#                   $(MAINSRCDIR)/world_entities/environment.cc \
+#                   $(MAINSRCDIR)/world_entities/skysphere.cc \
+#                   $(MAINSRCDIR)/world_entities/skybox.cc \
+#                   $(MAINSRCDIR)/world_entities/terrain.cc \
+#                   $(MAINSRCDIR)/world_entities/weapon.cc \
+#                   $(MAINSRCDIR)/world_entities/projectile.cc \
+#                   $(MAINSRCDIR)/world_entities/satellite.cc \
+#                   $(MAINSRCDIR)/world_entities/character_attributes.cc \
+#                   $(MAINSRCDIR)/world_entities/test_gun.cc \
+#                   $(MAINSRCDIR)/world_entities/test_bullet.cc \
+#                   $(MAINSRCDIR)/world_entities/test_entity.cc \
+#                   $(MAINSRCDIR)/lib/coord/p_node.cc \
+#                   $(MAINSRCDIR)/lib/coord/null_parent.cc \
+#                   $(MAINSRCDIR)/lib/graphics/graphics_engine.cc \
+#                   $(MAINSRCDIR)/lib/graphics/light.cc \
+#                   $(MAINSRCDIR)/lib/graphics/text_engine.cc \
+#                   $(MAINSRCDIR)/lib/lang/base_object.cc \
+#                   $(MAINSRCDIR)/lib/util/ini_parser.cc \
+#                   $(MAINSRCDIR)/lib/util/substring.cc \
+#                   $(MAINSRCDIR)/lib/math/vector.cc \
+#                   $(MAINSRCDIR)/lib/math/curve.cc \
+#                   $(MAINSRCDIR)/glmenu/glmenu_imagescreen.cc \
+#                   $(MAINSRCDIR)/subprojects/benchmark.cc
+
+
+
+
Index: orxonox/trunk/src/subprojects/collision_detection/Makefile.in
===================================================================
--- orxonox/trunk/src/subprojects/collision_detection/Makefile.in	(revision 4678)
+++ orxonox/trunk/src/subprojects/collision_detection/Makefile.in	(revision 4679)
@@ -61,4 +61,7 @@
 	collision-p_node.$(OBJEXT) collision-null_parent.$(OBJEXT) \
 	collision-gui_gtk.$(OBJEXT) collision-test_entity.$(OBJEXT) \
+	collision-environment.$(OBJEXT) collision-animation.$(OBJEXT) \
+	collision-animation_player.$(OBJEXT) \
+	collision-animation3d.$(OBJEXT) \
 	collision-world_entity.$(OBJEXT)
 collision_OBJECTS = $(am_collision_OBJECTS)
@@ -74,7 +77,11 @@
 depcomp = $(SHELL) $(top_srcdir)/depcomp
 am__depfiles_maybe = depfiles
-@AMDEP_TRUE@DEP_FILES = ./$(DEPDIR)/collision-base_object.Po \
+@AMDEP_TRUE@DEP_FILES = ./$(DEPDIR)/collision-animation.Po \
+@AMDEP_TRUE@	./$(DEPDIR)/collision-animation3d.Po \
+@AMDEP_TRUE@	./$(DEPDIR)/collision-animation_player.Po \
+@AMDEP_TRUE@	./$(DEPDIR)/collision-base_object.Po \
 @AMDEP_TRUE@	./$(DEPDIR)/collision-camera.Po \
 @AMDEP_TRUE@	./$(DEPDIR)/collision-collision_detection.Po \
+@AMDEP_TRUE@	./$(DEPDIR)/collision-environment.Po \
 @AMDEP_TRUE@	./$(DEPDIR)/collision-framework.Po \
 @AMDEP_TRUE@	./$(DEPDIR)/collision-graphics_engine.Po \
@@ -239,4 +246,8 @@
                    $(MAINSRCDIR)/lib/gui/gui_gtk.cc \
                    $(MAINSRCDIR)/world_entities/test_entity.cc \
+                   $(MAINSRCDIR)/world_entities/environment.cc \
+                   $(MAINSRCDIR)/util/animation/animation.cc \
+                   $(MAINSRCDIR)/util/animation/animation_player.cc \
+                   $(MAINSRCDIR)/util/animation/animation3d.cc \
                    $(MAINSRCDIR)/world_entities/world_entity.cc
 
@@ -307,7 +318,11 @@
 	-rm -f *.tab.c
 
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/collision-animation.Po@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/collision-animation3d.Po@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/collision-animation_player.Po@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/collision-base_object.Po@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/collision-camera.Po@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/collision-collision_detection.Po@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/collision-environment.Po@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/collision-framework.Po@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/collision-graphics_engine.Po@am__quote@
@@ -613,4 +628,68 @@
 @AMDEP_TRUE@@am__fastdepCXX_FALSE@	$(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
 @am__fastdepCXX_FALSE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(collision_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -c -o collision-test_entity.obj `if test -f '$(MAINSRCDIR)/world_entities/test_entity.cc'; then $(CYGPATH_W) '$(MAINSRCDIR)/world_entities/test_entity.cc'; else $(CYGPATH_W) '$(srcdir)/$(MAINSRCDIR)/world_entities/test_entity.cc'; fi`
+
+collision-environment.o: $(MAINSRCDIR)/world_entities/environment.cc
+@am__fastdepCXX_TRUE@	if $(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(collision_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -MT collision-environment.o -MD -MP -MF "$(DEPDIR)/collision-environment.Tpo" -c -o collision-environment.o `test -f '$(MAINSRCDIR)/world_entities/environment.cc' || echo '$(srcdir)/'`$(MAINSRCDIR)/world_entities/environment.cc; \
+@am__fastdepCXX_TRUE@	then mv -f "$(DEPDIR)/collision-environment.Tpo" "$(DEPDIR)/collision-environment.Po"; else rm -f "$(DEPDIR)/collision-environment.Tpo"; exit 1; fi
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='$(MAINSRCDIR)/world_entities/environment.cc' object='collision-environment.o' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	depfile='$(DEPDIR)/collision-environment.Po' tmpdepfile='$(DEPDIR)/collision-environment.TPo' @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	$(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(collision_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -c -o collision-environment.o `test -f '$(MAINSRCDIR)/world_entities/environment.cc' || echo '$(srcdir)/'`$(MAINSRCDIR)/world_entities/environment.cc
+
+collision-environment.obj: $(MAINSRCDIR)/world_entities/environment.cc
+@am__fastdepCXX_TRUE@	if $(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(collision_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -MT collision-environment.obj -MD -MP -MF "$(DEPDIR)/collision-environment.Tpo" -c -o collision-environment.obj `if test -f '$(MAINSRCDIR)/world_entities/environment.cc'; then $(CYGPATH_W) '$(MAINSRCDIR)/world_entities/environment.cc'; else $(CYGPATH_W) '$(srcdir)/$(MAINSRCDIR)/world_entities/environment.cc'; fi`; \
+@am__fastdepCXX_TRUE@	then mv -f "$(DEPDIR)/collision-environment.Tpo" "$(DEPDIR)/collision-environment.Po"; else rm -f "$(DEPDIR)/collision-environment.Tpo"; exit 1; fi
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='$(MAINSRCDIR)/world_entities/environment.cc' object='collision-environment.obj' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	depfile='$(DEPDIR)/collision-environment.Po' tmpdepfile='$(DEPDIR)/collision-environment.TPo' @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	$(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(collision_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -c -o collision-environment.obj `if test -f '$(MAINSRCDIR)/world_entities/environment.cc'; then $(CYGPATH_W) '$(MAINSRCDIR)/world_entities/environment.cc'; else $(CYGPATH_W) '$(srcdir)/$(MAINSRCDIR)/world_entities/environment.cc'; fi`
+
+collision-animation.o: $(MAINSRCDIR)/util/animation/animation.cc
+@am__fastdepCXX_TRUE@	if $(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(collision_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -MT collision-animation.o -MD -MP -MF "$(DEPDIR)/collision-animation.Tpo" -c -o collision-animation.o `test -f '$(MAINSRCDIR)/util/animation/animation.cc' || echo '$(srcdir)/'`$(MAINSRCDIR)/util/animation/animation.cc; \
+@am__fastdepCXX_TRUE@	then mv -f "$(DEPDIR)/collision-animation.Tpo" "$(DEPDIR)/collision-animation.Po"; else rm -f "$(DEPDIR)/collision-animation.Tpo"; exit 1; fi
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='$(MAINSRCDIR)/util/animation/animation.cc' object='collision-animation.o' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	depfile='$(DEPDIR)/collision-animation.Po' tmpdepfile='$(DEPDIR)/collision-animation.TPo' @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	$(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(collision_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -c -o collision-animation.o `test -f '$(MAINSRCDIR)/util/animation/animation.cc' || echo '$(srcdir)/'`$(MAINSRCDIR)/util/animation/animation.cc
+
+collision-animation.obj: $(MAINSRCDIR)/util/animation/animation.cc
+@am__fastdepCXX_TRUE@	if $(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(collision_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -MT collision-animation.obj -MD -MP -MF "$(DEPDIR)/collision-animation.Tpo" -c -o collision-animation.obj `if test -f '$(MAINSRCDIR)/util/animation/animation.cc'; then $(CYGPATH_W) '$(MAINSRCDIR)/util/animation/animation.cc'; else $(CYGPATH_W) '$(srcdir)/$(MAINSRCDIR)/util/animation/animation.cc'; fi`; \
+@am__fastdepCXX_TRUE@	then mv -f "$(DEPDIR)/collision-animation.Tpo" "$(DEPDIR)/collision-animation.Po"; else rm -f "$(DEPDIR)/collision-animation.Tpo"; exit 1; fi
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='$(MAINSRCDIR)/util/animation/animation.cc' object='collision-animation.obj' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	depfile='$(DEPDIR)/collision-animation.Po' tmpdepfile='$(DEPDIR)/collision-animation.TPo' @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	$(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(collision_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -c -o collision-animation.obj `if test -f '$(MAINSRCDIR)/util/animation/animation.cc'; then $(CYGPATH_W) '$(MAINSRCDIR)/util/animation/animation.cc'; else $(CYGPATH_W) '$(srcdir)/$(MAINSRCDIR)/util/animation/animation.cc'; fi`
+
+collision-animation_player.o: $(MAINSRCDIR)/util/animation/animation_player.cc
+@am__fastdepCXX_TRUE@	if $(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(collision_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -MT collision-animation_player.o -MD -MP -MF "$(DEPDIR)/collision-animation_player.Tpo" -c -o collision-animation_player.o `test -f '$(MAINSRCDIR)/util/animation/animation_player.cc' || echo '$(srcdir)/'`$(MAINSRCDIR)/util/animation/animation_player.cc; \
+@am__fastdepCXX_TRUE@	then mv -f "$(DEPDIR)/collision-animation_player.Tpo" "$(DEPDIR)/collision-animation_player.Po"; else rm -f "$(DEPDIR)/collision-animation_player.Tpo"; exit 1; fi
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='$(MAINSRCDIR)/util/animation/animation_player.cc' object='collision-animation_player.o' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	depfile='$(DEPDIR)/collision-animation_player.Po' tmpdepfile='$(DEPDIR)/collision-animation_player.TPo' @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	$(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(collision_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -c -o collision-animation_player.o `test -f '$(MAINSRCDIR)/util/animation/animation_player.cc' || echo '$(srcdir)/'`$(MAINSRCDIR)/util/animation/animation_player.cc
+
+collision-animation_player.obj: $(MAINSRCDIR)/util/animation/animation_player.cc
+@am__fastdepCXX_TRUE@	if $(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(collision_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -MT collision-animation_player.obj -MD -MP -MF "$(DEPDIR)/collision-animation_player.Tpo" -c -o collision-animation_player.obj `if test -f '$(MAINSRCDIR)/util/animation/animation_player.cc'; then $(CYGPATH_W) '$(MAINSRCDIR)/util/animation/animation_player.cc'; else $(CYGPATH_W) '$(srcdir)/$(MAINSRCDIR)/util/animation/animation_player.cc'; fi`; \
+@am__fastdepCXX_TRUE@	then mv -f "$(DEPDIR)/collision-animation_player.Tpo" "$(DEPDIR)/collision-animation_player.Po"; else rm -f "$(DEPDIR)/collision-animation_player.Tpo"; exit 1; fi
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='$(MAINSRCDIR)/util/animation/animation_player.cc' object='collision-animation_player.obj' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	depfile='$(DEPDIR)/collision-animation_player.Po' tmpdepfile='$(DEPDIR)/collision-animation_player.TPo' @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	$(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(collision_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -c -o collision-animation_player.obj `if test -f '$(MAINSRCDIR)/util/animation/animation_player.cc'; then $(CYGPATH_W) '$(MAINSRCDIR)/util/animation/animation_player.cc'; else $(CYGPATH_W) '$(srcdir)/$(MAINSRCDIR)/util/animation/animation_player.cc'; fi`
+
+collision-animation3d.o: $(MAINSRCDIR)/util/animation/animation3d.cc
+@am__fastdepCXX_TRUE@	if $(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(collision_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -MT collision-animation3d.o -MD -MP -MF "$(DEPDIR)/collision-animation3d.Tpo" -c -o collision-animation3d.o `test -f '$(MAINSRCDIR)/util/animation/animation3d.cc' || echo '$(srcdir)/'`$(MAINSRCDIR)/util/animation/animation3d.cc; \
+@am__fastdepCXX_TRUE@	then mv -f "$(DEPDIR)/collision-animation3d.Tpo" "$(DEPDIR)/collision-animation3d.Po"; else rm -f "$(DEPDIR)/collision-animation3d.Tpo"; exit 1; fi
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='$(MAINSRCDIR)/util/animation/animation3d.cc' object='collision-animation3d.o' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	depfile='$(DEPDIR)/collision-animation3d.Po' tmpdepfile='$(DEPDIR)/collision-animation3d.TPo' @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	$(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(collision_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -c -o collision-animation3d.o `test -f '$(MAINSRCDIR)/util/animation/animation3d.cc' || echo '$(srcdir)/'`$(MAINSRCDIR)/util/animation/animation3d.cc
+
+collision-animation3d.obj: $(MAINSRCDIR)/util/animation/animation3d.cc
+@am__fastdepCXX_TRUE@	if $(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(collision_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -MT collision-animation3d.obj -MD -MP -MF "$(DEPDIR)/collision-animation3d.Tpo" -c -o collision-animation3d.obj `if test -f '$(MAINSRCDIR)/util/animation/animation3d.cc'; then $(CYGPATH_W) '$(MAINSRCDIR)/util/animation/animation3d.cc'; else $(CYGPATH_W) '$(srcdir)/$(MAINSRCDIR)/util/animation/animation3d.cc'; fi`; \
+@am__fastdepCXX_TRUE@	then mv -f "$(DEPDIR)/collision-animation3d.Tpo" "$(DEPDIR)/collision-animation3d.Po"; else rm -f "$(DEPDIR)/collision-animation3d.Tpo"; exit 1; fi
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	source='$(MAINSRCDIR)/util/animation/animation3d.cc' object='collision-animation3d.obj' libtool=no @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	depfile='$(DEPDIR)/collision-animation3d.Po' tmpdepfile='$(DEPDIR)/collision-animation3d.TPo' @AMDEPBACKSLASH@
+@AMDEP_TRUE@@am__fastdepCXX_FALSE@	$(CXXDEPMODE) $(depcomp) @AMDEPBACKSLASH@
+@am__fastdepCXX_FALSE@	$(CXX) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(collision_CPPFLAGS) $(CPPFLAGS) $(AM_CXXFLAGS) $(CXXFLAGS) -c -o collision-animation3d.obj `if test -f '$(MAINSRCDIR)/util/animation/animation3d.cc'; then $(CYGPATH_W) '$(MAINSRCDIR)/util/animation/animation3d.cc'; else $(CYGPATH_W) '$(srcdir)/$(MAINSRCDIR)/util/animation/animation3d.cc'; fi`
 
 collision-world_entity.o: $(MAINSRCDIR)/world_entities/world_entity.cc
@@ -798,4 +877,44 @@
 
 include $(MAINSRCDIR)/defs/include_paths.am
+
+#                   $(MAINSRCDIR)/util/loading/game_loader.cc \
+#                   $(MAINSRCDIR)/util/track/track_manager.cc \
+#                   $(MAINSRCDIR)/util/track/track_node.cc \
+#                   $(MAINSRCDIR)/util/track/pilot_node.cc \
+#                   $(MAINSRCDIR)/util/animation/animation.cc \
+#                   $(MAINSRCDIR)/util/animation/animation3d.cc \
+#                   $(MAINSRCDIR)/util/animation/animation_player.cc \
+#                   $(MAINSRCDIR)/util/object_manager.cc \
+#                   $(MAINSRCDIR)/util/garbage_collector.cc \
+#                   $(MAINSRCDIR)/util/resource_manager.cc \
+#                   $(MAINSRCDIR)/util/loading/factory.cc \
+#                   $(MAINSRCDIR)/util/loading/load_param.cc \
+#                   $(MAINSRCDIR)/util/state.cc \
+#                   $(MAINSRCDIR)/world_entities/world_entity.cc \
+#                   $(MAINSRCDIR)/world_entities/camera.cc \
+#                   $(MAINSRCDIR)/world_entities/player.cc \
+#                   $(MAINSRCDIR)/world_entities/environment.cc \
+#                   $(MAINSRCDIR)/world_entities/skysphere.cc \
+#                   $(MAINSRCDIR)/world_entities/skybox.cc \
+#                   $(MAINSRCDIR)/world_entities/terrain.cc \
+#                   $(MAINSRCDIR)/world_entities/weapon.cc \
+#                   $(MAINSRCDIR)/world_entities/projectile.cc \
+#                   $(MAINSRCDIR)/world_entities/satellite.cc \
+#                   $(MAINSRCDIR)/world_entities/character_attributes.cc \
+#                   $(MAINSRCDIR)/world_entities/test_gun.cc \
+#                   $(MAINSRCDIR)/world_entities/test_bullet.cc \
+#                   $(MAINSRCDIR)/world_entities/test_entity.cc \
+#                   $(MAINSRCDIR)/lib/coord/p_node.cc \
+#                   $(MAINSRCDIR)/lib/coord/null_parent.cc \
+#                   $(MAINSRCDIR)/lib/graphics/graphics_engine.cc \
+#                   $(MAINSRCDIR)/lib/graphics/light.cc \
+#                   $(MAINSRCDIR)/lib/graphics/text_engine.cc \
+#                   $(MAINSRCDIR)/lib/lang/base_object.cc \
+#                   $(MAINSRCDIR)/lib/util/ini_parser.cc \
+#                   $(MAINSRCDIR)/lib/util/substring.cc \
+#                   $(MAINSRCDIR)/lib/math/vector.cc \
+#                   $(MAINSRCDIR)/lib/math/curve.cc \
+#                   $(MAINSRCDIR)/glmenu/glmenu_imagescreen.cc \
+#                   $(MAINSRCDIR)/subprojects/benchmark.cc
 # Tell versions [3.59,3.63) of GNU make to not export all variables.
 # Otherwise a system limit (for SysV at least) may be exceeded.
Index: orxonox/trunk/src/world_entities/environment.cc
===================================================================
--- orxonox/trunk/src/world_entities/environment.cc	(revision 4678)
+++ orxonox/trunk/src/world_entities/environment.cc	(revision 4679)
@@ -32,4 +32,5 @@
 {
   this->setClassID(CL_ENVIRONMENT, "Environment");
+  this->model = (Model*)ResourceManager::getInstance()->load("models/reaplow.obj", OBJ, RP_CAMPAIGN);
 }
 
Index: orxonox/trunk/src/world_entities/test_entity.cc
===================================================================
--- orxonox/trunk/src/world_entities/test_entity.cc	(revision 4678)
+++ orxonox/trunk/src/world_entities/test_entity.cc	(revision 4679)
@@ -1,5 +1,5 @@
 
 
-/* 
+/*
    orxonox - the future of 3D-vertical-scrollers
 
@@ -13,5 +13,5 @@
    ### File Specific
    main-programmer: Patrick Boenzli
-   co-programmer: 
+   co-programmer:
 */
 
@@ -27,5 +27,5 @@
 
 TestEntity::TestEntity () : WorldEntity(), PhysicsInterface(this)
-{  
+{
   this->setClassID(CL_TEST_ENTITY, "TestEntity");
 
@@ -35,5 +35,5 @@
 
 
-TestEntity::~TestEntity () 
+TestEntity::~TestEntity ()
 {
   delete this->md2Model;
@@ -47,5 +47,5 @@
 
 
-void TestEntity::tick (float time) 
+void TestEntity::tick (float time)
 {
   this->md2Model->tick(time);
@@ -62,16 +62,17 @@
 
 
-void TestEntity::draw () 
+void TestEntity::draw ()
 {
   glMatrixMode(GL_MODELVIEW);
   glPushMatrix();
   float matrix[4][4];
-  
+
+
   glTranslatef (this->getAbsCoor ().x, this->getAbsCoor ().y, this->getAbsCoor ().z);
   this->getAbsDir().matrix (matrix);
   glMultMatrixf((float*)matrix);
-  
+  glScalef(0.2, 0.2, 0.2);
   this->md2Model->draw();
-  
+
 
   glPopMatrix();

Index: orxonox/trunk/src/subprojects/collision_detection/collision_detection.cc
===================================================================
--- orxonox/trunk/src/subprojects/collision_detection/collision_detection.cc	(revision 4678)
+++ orxonox/trunk/src/subprojects/collision_detection/collision_detection.cc	(revision 4679)
@@ -28,4 +28,5 @@
 #include "model.h"
 #include "test_entity.h"
+#include "environment.h"
 
 #include "graphics_engine.h"
@@ -39,4 +40,6 @@
 tList<WorldEntity>* entityList;
 
+int lastFrame, currentFrame, dt;
+
 void Framework::moduleInit(int argc, char** argv)
 {
@@ -44,21 +47,29 @@
 
   CDEngine::getInstance();
+
+  /* Simple Test */
   //CDEngine::getInstance()->debug();
 
+  /* MD2 Model Test */
 //   model = new MD2Model("models/tris.md2", "models/tris.pcx");
 //   model->tick(0.1f);
 //   CDEngine::getInstance()->debugSpawnTree(9, model->data->pVertices, model->data->numVertices);
 
+  /* OBJ - Model Test */
+//   mod = (Model*)ResourceManager::getInstance()->load("models/reaplow.obj", OBJ, RP_CAMPAIGN);
+//   CDEngine::getInstance()->debugSpawnTree(9, (sVec3D*)mod->getVertexArray(), mod->getVertexArrayCount());
+
+
+
   entityList = new tList<WorldEntity>();
 
   TestEntity* a = new TestEntity();
+  Environment* b = new Environment();
+  b->setRelCoor(0.0, 0.0, -10.0);
 
   entityList->add(a);
-
-
-  mod = (Model*)ResourceManager::getInstance()->load("models/reaplow.obj", OBJ, RP_CAMPAIGN);
-  CDEngine::getInstance()->debugSpawnTree(9, (sVec3D*)mod->getVertexArray(), mod->getVertexCount());
-
-  /* ligths */
+  entityList->add(b);
+
+
   LightManager* lightMan = LightManager::getInstance();
   lightMan->setAmbientColor(.1,.1,.1);
@@ -71,4 +82,6 @@
   drawMode = DRAW_MODEL;
   depth = 0;
+  dt = lastFrame = currentFrame = 0;
+
 
   moduleHelp();
@@ -184,13 +197,35 @@
 void Framework::moduleTick(float dt)
 {
+
+  currentFrame = SDL_GetTicks();
+  dt = currentFrame - lastFrame;
+
+  if( dt > 55)
+  {
+    float fps = 1000/dt;
+
+          // temporary, only for showing how fast the text-engine is
+    char tmpChar[20];
+    sprintf(tmpChar, "fps: %4.0f", fps);
+  }
+  else
+  {
+          /* the frame-rate is limited to 100 frames per second, all other things are for nothing.
+          */
+    SDL_Delay((unsigned int)(50-dt));
+    dt = 55;
+  }
+
+
   tIterator<WorldEntity>* iterator = entityList->getIterator(); /* get the iterator - JAVA style */
   WorldEntity* entity = iterator->nextElement();   /* this returns the FIRST element */
   while( entity != NULL)                        /* nextElement() will return NULL at the end */
   {
-    entity->tick(0.2);
+    entity->tick(0.1);
     entity = iterator->nextElement();       /* give back the next element or NULL if last */
   }
   delete iterator;
 
+  lastFrame = currentFrame;
 }
 
@@ -198,16 +233,15 @@
 void Framework::moduleDraw() const
 {
-  CDEngine::getInstance()->drawBV(depth, drawMode);
-
+  //CDEngine::getInstance()->drawBV(depth, drawMode);
   LightManager::getInstance()->draw();
 
-//   tIterator<WorldEntity>* iterator = entityList->getIterator(); /* get the iterator - JAVA style */
-//   WorldEntity* entity = iterator->nextElement();   /* this returns the FIRST element */
-//   while( entity != NULL)                        /* nextElement() will return NULL at the end */
-//   {
-//     entity->draw();
-//     entity = iterator->nextElement();       /* give back the next element or NULL if last */
-//   }
-//   delete iterator;
+  tIterator<WorldEntity>* iterator = entityList->getIterator(); /* get the iterator - JAVA style */
+  WorldEntity* entity = iterator->nextElement();   /* this returns the FIRST element */
+  while( entity != NULL)                        /* nextElement() will return NULL at the end */
+  {
+    entity->draw();
+    entity = iterator->nextElement();       /* give back the next element or NULL if last */
+  }
+  delete iterator;
   //model->draw();
 }